﻿using System;

namespace AudioMate
{
    public static class Tools
    {
        /// <summary>
        /// Removes all whitespace from a string.
        /// </summary>
        public static string TrimAll(string str) {
            var len = str.Length;
            var src = str.ToCharArray();
            var dstIdx = 0;
            for (var i = 0; i < len; i++) {
                var ch = src[i];
                switch (ch) {
                    case '\u0020': case '\u00A0': case '\u1680': case '\u2000': case '\u2001':
                    case '\u2002': case '\u2003': case '\u2004': case '\u2005': case '\u2006':
                    case '\u2007': case '\u2008': case '\u2009': case '\u200A': case '\u202F':
                    case '\u205F': case '\u3000': case '\u2028': case '\u2029': case '\u0009':
                    case '\u000A': case '\u000B': case '\u000C': case '\u000D': case '\u0085':
                        break;
                    default:
                        src[dstIdx++] = ch;
                        break;
                }
            }
            return new string(src, 0, dstIdx);
        }

        /// <summary>
        /// Removes extension from a file name
        /// </summary>
        public static string TrimFileExtension(string fileName)
        {
            var fileExtPos = fileName.LastIndexOf(".", StringComparison.InvariantCulture);
            if (fileExtPos >= 0) fileName = fileName.Substring(0, fileExtPos);
            return fileName;
        }

        /// <summary>
        /// Empty test for StorableStringChooserJSON choices
        /// </summary>
        public static bool IsEmptyChoice(string choice)
        {
            return string.IsNullOrEmpty(choice) || choice == "None";
        }

        /// <summary>
        /// Generates a unique ID
        /// </summary>
        public static string GenerateID()
        {
            return Guid.NewGuid().ToString("N");
        }

        /// <summary>
        /// Returns loaded scene file name
        /// </summary>
        public static string SceneSaveName
        {
            get
            {
                var idx = SuperController.singleton.currentLoadDir.IndexOf(":/", StringComparison.Ordinal);
                return idx >= 0 ? SuperController.singleton.currentLoadDir.Substring(0, idx + 2) : string.Empty;
            }
        }
    }
}
